@@ -5,11 +5,12 @@ from os.path import expanduser, isdir, dirname, exists, isfile, join
 from os import makedirs, remove
 import json
 import logging
-import threading
 from pprint import pprint
 from xdg import XDG_DATA_HOME, XDG_CACHE_HOME, XDG_CONFIG_HOME
 from enum import Enum
+from json_database.combo_lock import ComboLock
 
+from tempfile import gettempdir
 
 LOG = logging.getLogger("JsonDatabase")
 
@@ -21,7 +22,8 @@ class JsonStorage(dict):
 
     def __init__(self, path):
         super().__init__()
-        self.lock = threading.Lock()
+        lock_path = join(gettempdir(), path.split("/")[-1] + ".lock")
+        self.lock = ComboLock(lock_path)
         self.path = path
         if self.path:
             self.load_local(self.path)
